@@ -50,7 +50,7 @@ class AzureClient():
         blob_client = self.service.get_blob_client(container=self.bucket_name,
                                                    blob=dst_file)
         with open(src_file, "rb") as data:
-            blob_client.upload_blob(data, max_concurrency=4)
+            blob_client.upload_blob(data, max_concurrency=4, overwrite=True)
 
     def upload_files(self, folder_id, selected_chunks, folder_chunks, do_tar=False, do_compress=False):
         print('DoTar {}, DoCompress {}'.format(do_tar, do_compress))
@@ -78,13 +78,13 @@ class AzureClient():
             tar.close()
             blob_client = self.service.get_blob_client(container=self.bucket_name, blob=f"{folder_id}/{folder_id}{ext}")
             with open(folder_compress, "rb") as data:
-                blob_client.upload_blob(data, max_concurrency=4)
+                blob_client.upload_blob(data, max_concurrency=4, overwrite=True)
         else:
             for chunk in selected_chunks:
                 blob_client = self.service.get_blob_client(container=self.bucket_name,
                                                            blob=f"{folder_id}/{chunk}")
                 with open(f"{folder_chunks}/{chunk}", "rb") as data:
-                    blob_client.upload_blob(data, max_concurrency=4)
+                    blob_client.upload_blob(data, max_concurrency=4, overwrite=True)
 
     def download_file(self, folder_id, selected_chunk, output_folder):
         if not os.path.exists(output_folder):
@@ -121,7 +121,7 @@ class AzureClient():
             tar.close()
             blob_client = self.service.get_blob_client(container=self.bucket_name, blob=f"{dst_folder}{ext}")
             with open(folder_compress, "rb") as data:
-                blob_client.upload_blob(data, max_concurrency=4)
+                blob_client.upload_blob(data, max_concurrency=4, overwrite=True)
         else:
             folder = os.fsencode(src_folder)
             for file in os.listdir(folder):
@@ -130,7 +130,7 @@ class AzureClient():
                     blob_client = self.service.get_blob_client(container=self.bucket_name,
                                                                blob=f"{dst_folder}/{file.decode('utf-8')}")
                     with open(file_path, "rb") as data:
-                        blob_client.upload_blob(data, max_concurrency=4)
+                        blob_client.upload_blob(data, max_concurrency=4, overwrite=True)
 
     def list_files_folder(self, folder):
         folder = folder.lstrip("/")
